<?php
/*
Plugin Name: WooCommerce SKU to Barcode (EasyToolsWP)
Description: Converts SKUs to barcodes on single product pages with Libre Barcode 39 Text and allows font selection.
Version: 1.1
Author: EasyToolsWP
*/

// Hovedfunktionalitet
function wc_sku_to_barcode_enqueue_styles() {
    $font = get_option('wc_sku_to_barcode_font', 'Libre Barcode 39 Text');
    // Tilføj stregkodeskrifttypen til temaet
    wp_enqueue_style('barcode-font', 'https://fonts.googleapis.com/css2?family=' . urlencode($font) . '&display=swap');
}
add_action('wp_enqueue_scripts', 'wc_sku_to_barcode_enqueue_styles');

function wc_sku_to_barcode_display($sku) {
    if (empty($sku)) return '';

    // Hent skrifttype fra indstillinger
    $font = get_option('wc_sku_to_barcode_font', 'Libre Barcode 39 Text');

    // Format SKU til stregkode format
    $barcode = '*' . strtoupper($sku) . '*';

    // Returner HTML til stregkoden
    return '<span style="font-family: \'' . esc_attr($font) . '\', sans-serif; font-size: 24px;">' . esc_html($barcode) . '</span>';
}

// Tilføj stregkode efter produktets SKU
function wc_sku_to_barcode_on_single_product() {
    global $product;
    if ($product) {
        $sku = $product->get_sku();
        if ($sku) {
            echo '<div class="wc-sku-barcode">' . wc_sku_to_barcode_display($sku) . '</div>';
        }
    }
}
add_action('woocommerce_single_product_summary', 'wc_sku_to_barcode_on_single_product', 25);

// Tilføj admin-side for skrifttypevalg
function wc_sku_to_barcode_admin_menu() {
    add_options_page(
        'SKU to Barcode Settings',
        'SKU to Barcode',
        'manage_options',
        'wc_sku_to_barcode',
        'wc_sku_to_barcode_settings_page'
    );
}
add_action('admin_menu', 'wc_sku_to_barcode_admin_menu');

function wc_sku_to_barcode_settings_page() {
    ?>
    <div class="wrap">
        <h1>SKU to Barcode Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('wc_sku_to_barcode_options');
            do_settings_sections('wc_sku_to_barcode');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function wc_sku_to_barcode_settings_init() {
    register_setting('wc_sku_to_barcode_options', 'wc_sku_to_barcode_font');

    add_settings_section(
        'wc_sku_to_barcode_section',
        'Stregkodeskrifttype',
        null,
        'wc_sku_to_barcode'
    );

    add_settings_field(
        'wc_sku_to_barcode_font',
        'Vælg Stregkodeskrifttype',
        'wc_sku_to_barcode_font_field',
        'wc_sku_to_barcode',
        'wc_sku_to_barcode_section'
    );
}
add_action('admin_init', 'wc_sku_to_barcode_settings_init');

function wc_sku_to_barcode_font_field() {
    $font = get_option('wc_sku_to_barcode_font', 'Libre Barcode 39 Text');
    ?>
    <select name="wc_sku_to_barcode_font">
        <option value="Libre Barcode 39 Text" <?php selected($font, 'Libre Barcode 39 Text'); ?>>Libre Barcode 39 Text</option>
        <!-- Tilføj andre skrifttyper her, hvis ønskes -->
    </select>
    <?php
}